==> qmmp-0.9.2-1.00.tar.gz: qmmp-1.0.0/src/plugins/Input/sid/translations/sid_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="69"/>
        <source>SID Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="71"/>
        <source>SID Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="125"/>
        <source>About SID Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="126"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="127"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="128"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished">作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>取样率：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/sid/translations/sid_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="78"/>
        <source>SID Plugin</source>
        <translation>SID插件</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="80"/>
        <source>SID Files</source>
        <translation>SID文件</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="134"/>
        <source>About SID Audio Plugin</source>
        <translation>关于SID音频插件</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="135"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>Qmmp播放器SID音频插件</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="136"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>本插件使用libsidplayfp文件库播放科莫多64音乐文件</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="137"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>SID插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>快速重新取样</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>取样率：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>HVSC数据库文件：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>重取样方式：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>默认歌曲长度，秒：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>开启HVSC歌曲长度数据库</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>模拟：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation>44100赫兹</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation>48000赫兹</translation>
    </message>
</context>
</TS>
